@@ -10,11 +10,11 @@ Date::Utility - A class that represents a datetime in various format
 
 =head1 VERSION
 
-Version 1.05
+Version 1.06
 
 =cut
 
-our $VERSION = '1.05';
+our $VERSION = '1.06';
 
 =head1 SYNOPSIS
 
@@ -66,6 +66,7 @@ has [qw(
         date
         datetime
         date_ddmmyy
+        date_ddmmyyyy
         date_ddmmmyy
         date_yyyymmdd
         date_ddmmmyyyy
@@ -456,6 +457,7 @@ my $date_only         = qr/^([0-3]?[0-9])-($mon_re)-([0-9]{2}|[0-9]{4})$/;
 my $date_with_time    = qr /^([0-3]?[0-9])-($mon_re)-([0-9]{2}) ([0-2]?[0-9])[h:]([0-5][0-9])(?::)?([0-5][0-9])?(?:GMT)?$/;
 my $numeric_date_only = qr/^([12][0-9]{3})-?([01]?[0-9])-?([0-3]?[0-9])$/;
 my $fully_specced     = qr/^([12][0-9]{3})-?([01]?[0-9])-?([0-3]?[0-9])(?:T|\s)?([0-2]?[0-9]):?([0-5]?[0-9]):?([0-5]?[0-9])(\.[0-9]+)?(?:Z)?$/;
+my $numeric_date_only_dd_mm_yyyy = qr/^([0-3]?[0-9])-([01]?[0-9])-([12][0-9]{3})$/;
 
 sub _parse_datetime_param {
     my $datetime = shift;
@@ -487,6 +489,10 @@ sub _parse_datetime_param {
         $day   = $3;
         $month = $2;
         $year  = $1;
+    } elsif ($datetime =~ $numeric_date_only_dd_mm_yyyy) {
+        $day   = $1;
+        $month = $2;
+        $year  = $3;
     } elsif ($datetime =~ $fully_specced) {
         $day    = $3;
         $month  = $2;
@@ -495,7 +501,6 @@ sub _parse_datetime_param {
         $minute = $5;
         $second = $6;
     }
-
     # Type constraints mean we can't ever end up in here.
     else {
         confess "Invalid datetime format: $datetime";
@@ -661,6 +666,18 @@ sub _build_date_ddmmyy {
     return join('-', (sprintf('%02d', $self->day_of_month), sprintf('%02d', $self->month), sprintf('%02d', $self->year_in_two_digit)));
 }
 
+=head2 date_ddmmyyyy
+
+Returns date in this format "dd-mm-yyyy" (28-02-2010)
+
+=cut
+
+sub _build_date_ddmmyyyy {
+    my $self = shift;
+
+    return join('-', (sprintf('%02d', $self->day_of_month), sprintf('%02d', $self->month), $self->year));
+}
+
 =head2 date_yyyymmdd
 
 Returns date in this format "yyyy-mm-dd" (2010-03-02)
@@ -1003,7 +1020,7 @@ __END__
 
 =head1 DEPENDENCIES
 
-=over 7
+=over 4
 
 =item L<Moose>
 
@@ -1019,6 +1036,8 @@ __END__
 
 =item L<Try::Tiny>
 
+=back
+
 
 =head1 AUTHOR
 
